##  Mapping Processes
Mapping the process primarily involves selecting a sync mode to manage data updates and deletions, followed by configuring the synchronization hierarchy by selecting relevant SAP Signavio directories. This is done in the Basic Configuration tab of the integration configuration page
![Basic Configuration Tab of the Integration Configuration](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754b2877a4410149a789063dce1f2af_LowRes.png)
Basic Configuration Tab of the Integration Configuration
